#
# spec file for package python-Kivy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if %{suse_version} > 1500
%define mypython python3
%define __mypython %{__python3}
%else
%{?sle15_python_module_pythons}
%define mypython %pythons
%define __mypython %{expand:%%__%{pythons}}
%endif
%define plainpython python
Name:           python-Kivy
Version:        2.3.0
Release:        1.4
Summary:        Hardware-accelerated multitouch application library
License:        Apache-2.0 AND MIT AND LGPL-2.1-or-later AND GPL-2.0-or-later AND GPL-3.0-only AND BSD-3-Clause
URL:            https://kivy.org/
Source:         https://github.com/kivy/kivy/archive/%{version}.tar.gz#/kivy-%{version}.tar.gz
Source99:       python-Kivy.rpmlintrc
BuildRequires:  %{mypython}-Sphinx
BuildRequires:  %{python_module Cython with %python-Cython < 3}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module dbus-python}
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyenchant}
BuildRequires:  %{python_module pygments}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  Mesa-devel
BuildRequires:  Mesa-dri
BuildRequires:  SDL2-devel
BuildRequires:  SDL2_image-devel
BuildRequires:  SDL2_mixer-devel
BuildRequires:  SDL2_ttf-devel
BuildRequires:  dbus-1
BuildRequires:  fdupes
BuildRequires:  gstreamer-plugins-bad
BuildRequires:  gstreamer-plugins-good
BuildRequires:  mtdev
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  xclip
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(pangoft2)
Requires:       mtdev
Requires:       python-Pygments
Requires:       python-docutils
Requires:       xclip
# Not listed in setup.cfg but imported in core/spelling/spelling_enchant.py
Requires:       python-pyenchant
# SECTION extra [base] (and [full])
Requires:       python-Pillow
Requires:       python-requests
# /SECTION
# SECTION test
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest-xvfb}
BuildRequires:  %{python_module responses}
# /SECTION
# Section doc
BuildRequires:  %{mypython}-Sphinx
BuildRequires:  %{mypython}-sphinxcontrib-jquery
#BuildRequires:  %%{mypython}-sphinxcontrib-actdiag
#BuildRequires:  %%{mypython}-sphinxcontrib-blockdiag
#BuildRequires:  %%{mypython}-sphinxcontrib-nwdiag
#BuildRequires:  %%{mypython}-sphinxcontrib-seqdiag
# /SECTION
Recommends:     python-opencv
%python_subpackages

%description
Kivy is a library for development of applications that make use of
user interfaces, such as multi-touch apps.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}
Requires:       %plainpython(abi) = %{python_version}

%description    devel
Kivy is a library for development of applications that make use of
user interfaces, such as multi-touch apps.

This package contains the headers and source files for extending kivy

%package     -n %{name}-doc
Summary:        Documentation for Kivy, a multitouch application library
Provides:       %{python_module Kivy-doc = %{version}}
BuildArch:      noarch

%description -n %{name}-doc
Kivy is a library for development of applications that make use of
user interfaces, such as multi-touch apps.

%prep
%setup -q -n kivy-%{version}
# remove the legacy garden install script as python requirement, get it from PyPI or https://github.com/kivy-garden/garden/ if you need it
sed -i '/Kivy-Garden/d' setup.cfg
# remove shebang
sed -i '1{ /^#!/d; }' kivy/tools/kviewer.py \
  kivy/tools/pep8checker/pep8.py \
  kivy/tools/pep8checker/pre-commit.githook
# remove executable bit
find examples -type f -executable -exec chmod -x {} \;
rm examples/demo/pictures/images/.empty # Remove empty file
rm -r examples/audio # Remove content with non-commercial only license (bnc#749340)
# fix shebang
sed -i "/^#!/ c #!%{__mypython}" kivy/tools/image-testsuite/gimp28-testsuite.py
sed -i "/^#!/ c #!`which sh`" kivy/tools/image-testsuite/imagemagick-testsuite.sh
# remove benchmark from tests
sed -i /addopts/d pyproject.toml
chmod -x kivy/tools/pep8checker/pre-commit.githook

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export KIVY_SPLIT_EXAMPLES=1
%pyproject_wheel
# create docs
pushd doc
sed -e '/^PYTHON/ s|python|%{__mypython}|' \
    -e '/^SPHINXOPTS	/s/$/ %{?_smp_mflags}/' \
    -i Makefile
export PYTHONPATH=`ls -d ../build/lib*`
make %{?_smp_mflags} PYTHON=%{__mypython} html && rm -r build/html/.buildinfo
popd

%install
%pyproject_install
%{python_expand #
%fdupes %{buildroot}%{$python_sitearch}/kivy
find %{buildroot}%{$python_sitearch}/kivy -name '*.h' \
  | sed 's|%{buildroot}||' \
  | tee kivy-devel-%{$python_bin_suffix}.files \
  | sed 's|^/|%%exclude /|' > kivy-exclude-devel-%{$python_bin_suffix}.files
}
# workaround to make fdupes its magic as if %%doc macro is used
# would be used after fdupes so rpmlint would complain about duplicates...
install -dm0755 %{buildroot}%{_docdir}/%{name}-doc
cp -a doc/build/html %{buildroot}/%{_docdir}/%{name}-doc/
cp -a examples %{buildroot}/%{_docdir}/%{name}-doc/
%fdupes %{buildroot}%{_docdir}/%{name}-doc

%check
# we don't care about speed inside obs
donttest="benchmark"
# no network (or localhost resolution) in obs
donttest="$donttest or test_urlrequest_urllib or test_remote_zipsequence"
# avoid collection errors
mv kivy kivy.notinpath
pushd examples
%pytest_arch --pyargs kivy -k "not ($donttest)"
popd

%files %{python_files} -f kivy-exclude-devel-%{python_bin_suffix}.files
%license LICENSE
%doc AUTHORS
%{python_sitearch}/kivy
%{python_sitearch}/Kivy-%{version}.dist-info

%files %{python_files devel} -f kivy-devel-%{python_bin_suffix}.files
%doc doc/sources/changelog.rst

%files -n %{name}-doc
%doc %{_docdir}/%{name}-doc

%changelog
* Sat Jan 13 2024 Dirk Müller <dmueller@suse.com>
- update to 2.3.0:
  * [:repo:`8298`]: core-providers (audio): removes deprecated
    status property
  * [:repo:`8299`]: core-providers (audio): removes deprecated
    filename property
  * [:repo:`8300`]: core-providers (window): Removes deprecated
    toggle_fullscreen method
  * [:repo:`8309`]: Add graphics with antialiasing:
    SmoothRectangle, SmoothEllipse, SmoothRoundedRectangle,
    SmoothQuad and SmoothTriangle
  * [:repo:`8313`]: Linux dependencies: Build libpng16 for
    freetype so can render colored emoji
  * [:repo:`8315`]: Remove the extra position added to undo list
    while using Shift key
  * [:repo:`8317`]: macOS dependencies: Build libpng16 for
    freetype, so can render colored emoji
  * [:repo:`8495`]: Honour multiline=True/False while pasting,
    Fix Scroll after backspace and undo.
  * [:repo:`8497`]: Added spanish layout json for the vkeyboard
  * [:repo:`8503`]: Pillow text provider: use get_bbox when
    get_size is not available. Allows latest versions of pillow
    to work along with older ones.
  * [:repo:`8459`]: Deprecate kivy.utils.interpolate and improve
    related docs
  * [:repo:`8206`]: Improved KV-lang parser error info when
    indentation is invalid
  * [:repo:`8301`]: Rework custom garden importer to avoid usage
    of imp module (removed in Python 3.12)
  * [:repo:`8357`]: Apply style fixes as suggested by new flake8
    version
  * [:repo:`8443`]: Slow down no-response bot
  * [:repo:`8447`]: Remove bountysource link, as bountysource
    looks died.
  * [:repo:`8453`]: Update support-requests action
  * [:repo:`8459`]: Deprecate kivy.utils.interpolate and improve
    related docs
  * [:repo:`8428`]: Add balenalib/raspberrypi3-debian-
    python:3.11-bookworm to rpi builds for newer  RPi OS
  * [:repo:`8276`]: Image: Fix stencil instructions leaking to
    user canvas.before/canvas instructions
  * [:repo:`8315`]: Remove the extra position added to undo list
    while using Shift key
  * [:repo:`8389`]: Fixes a regression that prevents the setting
    panel to load
  * [:repo:`8492`]: ColorWheel and ColorPicker: simplify,  cleans
    up and add tests
  * [:repo:`8495`]: Honour multiline=True/False while pasting,
    Fix Scroll after backspace and undo.
  * [:repo:`8535`]: Fix text attributes not changing after the
    settings panel is opened
  * [:repo:`8345`]: Prevent apps from crashing when sys.stderr is
    None (pythonw and pyinstaller 5.7)
  * [:repo:`8383`]: Fix stencil operations when KIVY_WINDOW=x11
  * [:repo:`8218`]: Remove redundant from kivy.base import
    EventLoop import causing crashes in window_sdl2
  * [:repo:`8296`]: WindowSDL: Add opacity feature
  * [:repo:`8298`]: core-providers (audio): removes deprecated
    status property
  * [:repo:`8299`]: core-providers (audio): removes deprecated
    filename property
  * [:repo:`8300`]: core-providers (window): Removes deprecated
    toggle_fullscreen method
  * [:repo:`8342`]: Clipboard: fixes blank string being pasted
    into clipboard when using the default win32 backend
  * [:repo:`8435`]: Fixes markup [sup] followed by [sub] doesn't
    work (issue #8077)
  * [:repo:`8446`]: Window.mouse_pos is incorrect if the scale
    factor in Windows is not 100%%.
  * [:repo:`8490`]: SetClipboardData requires a memory object
    allocated with GMEM_MOVEABLE (and locks)
  * [:repo:`8503`]: Pillow text provider: use get_bbox when
    get_size is not available. Allows latest versions of pillow
    to work along with older ones.
  * [:repo:`8510`]: New feature: Add limit_render_to_text_bbox to
    Label to limit text rendering to the text bounding box,
    improving Label alignments.
  * [:repo:`8511`]: PIL text provider: Ensure consistent text
    height to prevent text from bouncing when typing
  * [:repo:`8540`]: PIL text provider: Do not render text if font
    size is < 1
  * [:repo:`8497`]: Added spanish layout json for the vkeyboard
  * [:repo:`8253`]: Update version to 2.3.0.dev0 for development
  * [:repo:`8310`]: pin Pillow version to 9.5.0
  * [:repo:`8313`]: Linux dependencies: Build libpng16 for
    freetype so can render colored emoji
  * [:repo:`8317`]: macOS dependencies: Build libpng16 for
    freetype, so can render colored emoji
  * [:repo:`8326`]: Add support for Cython==3.x.x and increase
    cython_min version
  * [:repo:`8393`]: Add support for Python 3.12 (tests, wheels)
  * [:repo:`8505`]: Restrict the Pillow version to >=9.5.0,<11
  * [:repo:`8513`]: Make sure build dependencies are installed
    for Kivy.app, and use default python version provided by
    create-osx-bundle.sh
  * [:repo:`8251`]: Ensures that jQuery is always installed (on
    newer sphinx versions is not the default)
  * [:repo:`8274`]: Add disclaimer to use RecycleView instead of
    ScrollView for large datasets
  * [:repo:`8303`]: Copy-edit to layouts.rst
  * [:repo:`8308`]: Copy edits: Standardize on spelling
  * [:repo:`8324`]: Fix linux dependencies build instructions
  * [:repo:`8347`]: RecycleDataAdapter: Fixed typo in class
    docstring
  * [:repo:`8349`]: ObjectProperty: Fixed ValueError message in
    "convert" method.
  * [:repo:`8377`]: Add doc for Selection handles.
  * [:repo:`8411`]: Removes broken support e-mail address in the
    README.md, and improve the support section
  * [:repo:`8440`]: Fix #8438: SyntaxWarnings during doc
    generation.
  * [:repo:`8442`]: Edit Contact Us page in docs
  * [:repo:`8464`]: Correct documentation of schedule_interval
  * [:repo:`8493`]: Correct ActionBar documentation
  * [:repo:`8514`]: Make doc structure consistent and up-to-date
  * [:repo:`8542`]: Happy new year! Updated copyright year to
    2024
  * [:repo:`8228`]: Added a flag to force the use of custom
    drawing line function.
  * [:repo:`8270`]: Allow Scale and Translate to take x, y and z
    as kwargs. Removes deprecated Scale().scale property.
  * [:repo:`8271`]: Fix SmoothLine rendering issues
  * [:repo:`8309`]: Add graphics with antialiasing:
    SmoothRectangle, SmoothEllipse, SmoothRoundedRectangle,
    SmoothQuad and SmoothTriangle
  * [:repo:`8374`]: Avoid multiple values for noadd in
    VertexInstruction
  * [:repo:`8375`]: Fix use of BoxShadow with canvas.add,
    canvas.insert and canvas.remove
  * [:repo:`8405`]: Introduce clear_stencil option in
    StencilPush, to allow disabling stencil clearing and improve
    GPU performance when using Stencil Instructions
  * [:repo:`8413`]: Expose new clear_stencil property in
    StencilPush
  * [:repo:`8415`]: Fix cgl_backend build with clang 16
* Sat Sep 30 2023 Ben Greiner <code@bnavigator.de>
- Add Make sure the docs still build with both Tumbleweed and
  sle15_pythons_module_pythons in 15.5
- Move to PEP517
- Re-enable test suite: it has come a long way since the ancient
  nosetest times
* Sun Aug 13 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.1:
  * Limit stencil to inner instructions on Image widget
  * Increase timeout of httpbin tests to reduce risk of failures on CI runs
  * Ensures that jQuery is always installed
* Fri Jun  2 2023 Daniel Donisa <daniel.donisa@suse.com>
- Update to version 2.2.0, see https://github.com/kivy/kivy/blob/2.2.0/doc/sources/changelog.rst
* Thu Aug 25 2022 Luigi Baldoni <aloisio@gmx.com>
- Add setuptools module as build requirement
* Wed Mar 23 2022 pgajdos@suse.com
- python-mock is not required for build
* Sun Mar  6 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.1.0, see changelog.rst
* Thu Dec 10 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.0.0, see changelog.rst
* Wed Apr  1 2020 Paolo Stivanin <info@paolostivanin.com>
- Remove nose dep as we are not running the tests
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Fri Aug  9 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.11.1 , no upstream changelog
* Tue Jun  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not restrict the Cython dependency to work with new releases
* Sat Jun  1 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.11.0 (see https://kivy.org/#changelog)
* Thu Feb 21 2019 Todd R <toddrme2178@gmail.com>
- Disable tests because they randomly timeout.
* Sat Jul 14 2018 jengelh@inai.de
- Trim redundancies from descriptions.
* Sat Jul  7 2018 aloisio@gmx.com
- Update to version 1.10.1 (see https://kivy.org/#changelog)
- Converted to single-spec
- Put documentation and examples into -doc subpackage
- Dropped python-Kivy-rpmlintrc
* Sat Mar 11 2017 sfalken@opensuse.org
- Edited %%files to explicitly package %%{_docdir}/%%{name} to clear
  unpackaged files builderror in openSUSE:Factory
* Mon Feb  6 2017 jmatejek@suse.com
- drop recommendation for obsolete GStreamer 0.10 (not necessary)
  and pycairo (not used at all)
* Mon Jan  4 2016 boris@steki.net
- updated to latest release 1.9.1
  + a lot of changes VERY SMALL cherry picked list follows
  - move to SDL2
  - implement Window.show_cursor for pygame and sdl2
  - Adds kivy namespaces.
  - audio_sdl2: support sequenced formats
  - Initial support for rendering of SVG
  - hid input: default is inverted now,
    also the invertion function was wrong
  - add error logging for opengl
  - core/audio: new pure-python/pyobjus AVFoundation audio player
- Added rpmlintrc file to filter out fsf address and python abi noise
- removed patch python-Kivy-Cython-0.21.patch as it is in package
* Mon Nov 10 2014 dimstar@opensuse.org
- Replace python-imaging BuildRequires and Requires with
  python-Pillow: The code actually does 'from PIL import image', so
  pythom-imaging would not even work.
* Thu Oct 16 2014 dimstar@opensuse.org
- Add python-Kivy-Cython-0.21.patch: Fix build with Cython 0.21.
* Wed Feb 19 2014 mvyskocil@suse.com
- Update to version 1.8.0
  * Python 3.3 support: It's finally here, using the same codebase! And
  we deliver also 3 portables for Windows, one that package Python 2.7
  and another with Python 3.3!
  * New media player named GstPlayer, based on Gstreamer 1.0. This
  player is currently used as a implementation for Audio and Video
  core provider. This allow us to not only use the latest Gstreamer
  and all the improvements done by them, but also have a common player
  for both Python 2.7 and 3.3 on desktop platforms.
  * Scrollview has been slightly enhanced to support smoother scrolling
  utilizing Matrix transformation by default. It also now supports
  scrolling through bars or content or both.
  * Widgets now can be disabled simply by using `disabled` property.
  * Textinput now has support for selection handles.
  * New Widgets!
  + ActionBar: Mimics Android’s own ActionBar appearance and
    mechanisms
  + Behaviors: ButtonBehavior, ToggleButtonBehavior, DragBehavior,
    just subclass a behavior to an existing widgets, and you get the
    behavior! (eg. class ImageButton(ButtonBehavior, Image))
  + PageLayout: A simple multi-page layout allowing flipping through
    pages using borders
  + SandBox (experimental): Runs itself and its children in an
    exception-catching sandbox
  * see https://groups.google.com/forum/#!topic/kivy-users/PePoXLXDYBk
  for more details
* Mon Sep 30 2013 speilicke@suse.com
- Change requires on python-enchant to python-pyenchant and drop
  the recommends for it. Enchant seems to be loaded from kivy/core
* Wed Sep 25 2013 p.drouand@gmail.com
- Update to version 1.7.2
  + No changelog available
* Sat May 18 2013 toddrme2178@gmail.com
- Update to version 1.7.0
  * no changelog available
- Added several dependencies mentioned in the documentation
* Mon Dec 17 2012 saschpe@suse.de
- Update to version 1.5.1:
  + Widgets
  - [#847] Avoid to react on scrollleft/right on Button + FileChooser
  + Graphics
  - [#856] Fix Line instruction
  + Examples
  - [#848,#855] Fix Kivy catalog to work from a different cwd
- Changes from version 1.5.0:
  + Core
  - [#731] BoundedNumericProperty can have float bounds
  - [#755] Fix SetWindowLongPtr on 32/64 Windows
  - [#768] Fix AsyncImage loader on iOS
  - [#778] Prevent the Pygame parachute if we don't have the required
  - [#779] Better DPI support, with new sp and dp units
  - [#783] New screen module for simulating different DPI devices
  - [#789] Fix on_resize dispatch on Windows and OSX
  - Allow multiple providers in Kivy env variables
  - Fix line off-by-one issue in Kv errors
  - New errorhandler/errorvalue in Property class
  - New experimental X11 window provider, that support transparent
  - Normalize android pressure and radius
  - Reduce gstreamer audio/video out-of-sync
  - Support ability to stop/restart the EventLoop
  + Graphics
  - [#481] Avoid error in case of multiple Canvas.rremove()
  - [#610] Add more information when GLEW fail to initialize
  - [#671] Allow source unicode filename in BindTexture
  - [#790] Allow to change Stencil operators
  - Avoid BGRA->RGBA conversion for OSX if the GPU support BRGA.
  - Fix issue with Cython 0.14, "by" is now considered as a keyword
  - Line: add bezier and bezier_precision properties
  - Line: fix missing ellipse/circle/rectangle in the Line constructor
  - Texture: always flip the texture vertically for Image and Label
  + Widgets
  - [#618] Raise exception if ScreenManager.start() is called twice
  - [#648] Avoid touch event propagation on ScreenManager transition
  - [#662] Enhance TextInput performance
  - [#706] Fix pos_hint Boxlayout calculation
  - [#725] Fix collapse management in Accordion
  - [#734] Fix widget opacity when passed in the constructor
  - [#736] Fix slider bug when min < 0, max < 0 and step > 0
  - [#737] Better swipe gesture detection for Carousel
  - [#747] Honor index in Carousel.add_widget() (and Bubble)
  - [#750] New CodeInput widget
  - [#771] Dispatch modalview.on_open after animation
  - [#785] Allow event binding in Widget constructor
  - [#819] Fix canvas positioning when inserting at first position
  - [#824] Add top-to-bottom + right-to-left Stacklayout orientations.
  - [#832] Fix shorten routine
  - Automatically register new Widget classes in Factory
  - Enhance ScrollView scrolling
  - Fix Carousel API, containers are now hidden, and
  - Fix Label.color property for markup labels
  - Multiples fixes to TabbedPanel (tab_strip, unbind, tab selection)
  + Others
  - [#670] New compass demo for Android using sensors
  - Many many fixes on the documentation, thanks for all the PR!
  - New KivyCatalog example: interactive Kv editor
  - Started Guide 2.0
* Mon Oct 22 2012 dmacvicar@suse.de
- Update to version 1.4.1:
  + Core
  - [#625] Extend NumericProperty to support DPI notation
  - [#660] Add callbacks support on ConfigParser for a (section, key)
  - [#666] Fix Markup text disapear on GL reloading
  - [#678] Enhance UrlRequest for small chunks, callbacks and GC
  - [#679] New Audio.get_pos()
  - [#680] Fix key translations on Keyboard
  - Force on_parent dispatching for children in a kv rule
  - Expose 'app' instance keyword in Kv language
  + Graphics
  - [#686] Added opacity support in the graphics pipeline
  - Enhanced Line instruction that support width, joint, cap.
  - Added Line.circle/ellipse/rectangle properties
  + Widgets
  - [#664] Fix TextInput crashes is some cases
  - [#686] New Widget.opacity property
  - [#690] New TextInput.background_normal/active
  - [#694] Fix Slider value when min and step > 0
  - [#676] Fix Carousel.remove_widget()
  - [#669] Fix SettingNumeric with int/float values
  - [#698] Enhance BoxLayout to support pos_hint
  - Fix ModalView background property
  + Windows
  - [#675] Fix WM_Touch / WM_Pen for 32 bits / 64 bits
  + Others
  - [#462] Fixes gstreamer packaging with PyInstaller
  - [#659] Updated documentation concerning PyInstaller 2.0
- Changes from 1.4.0:
  + Core
  - [#513] Fix nested template
  - [#547] Fix url loader with querystring
  - [#576] Markup text can be vertically aligned
  - [#585] Enhance add_widget() to raise an Exception on multiple parents
  - [#642] Support of smb:// in url loader with pysmb
  - Enhance AliasProperty to cache the result if use_cache is set to True
  - Enhance App.get_application_config() to get a correct config filename on all platforms
  - Fix Animation.stop_all() + new Animation.cancel()
  - Fix Property.unbind() for bounded methods
  + Graphics
  - [#516] Fix crash when loading 1bit image
  - [#546] Fix Quad() initialization
  + Widgets
  - [#543] Fix multiple content in TabbedPanel from Kv
  - [#549] Enhance TabbedPanel to introduce default_tab_class
  - [#562] Popup can now define the content in Kv
  - [#593] Enhance TextInput with select_all() and select_text() methods
  - [#658] Fix usage of Camera within Kv
  - Enhanced VideoPlayer to have pause ability and state property
  - Enhance Image widget to add keep_data for further pixel collision detection
  - New Carousel widget
  - New Checkbox widget
  - New Dropdown widget
  - New ModalView widget
  - New RelativeLayout, identical from FloatLayout with relative coordinates
  - New ScreenManager widget for changing views with transitions
  - New Slider.step property
  - New Spinner widget
  + Windows
  - [#621] Fix ghost touch due to a raise condition
  - Add python scripts into the PATH
  - Enhance input wm_touch/pen to be compatible with 64bits
  - Severals fixes around window resizing
  + Others
  - New Getting Started
  - Tons of documentation typo, fixes. Really, a ton.
* Tue Jun 26 2012 saschpe@suse.de
- Update to version 1.3.0:
  + Core
  - [#420] Fix pygame error when texture is too large
  - [#450] Updated Sound class to use Kivy properties
  - [#467] New Sound.length
  - [#484] New kivy.interactive module: doesn't break REPL anymore
  - [#487] Make default values in properties optionals
  - [#489] Replaced all relative import with absolute imports
  - [#498] Fixes Image to allow re-loading of image from disk
  - [#503] Renamed unicode parameter to codepoint in all on_key_*
  - Changed default screenshot to be PNG instead of JPEG
  - Enhance Kv lang rules lookup
  - Enhance Label initialitazion
  - Fixes crash on App when the configuration file cannot be read
  - Fixes for graphics reloading mechanism, force the GC before
  - New default UI theme
  - New KIVY_NO_CONFIG, KIVY_NO_FILELOG, KIVY_NO_CONSOLELOG env
  - New kivy.utils.escape_markup() to escape untrusted text when
  - Support MacOSX clipboard
  + Graphics
  - [#118] Fixes for glColorMask on android
  - [#447] Add new ClearColor and ClearBuffers instructions
  - [#463] Fixes glGetIntegerv with new Cython
  - [#479] Fixes for Translate instance when args passed in on
  - Avoid drawing of empty VBO
  - Enhance Stencil instruction, you can nest up to 128 layers instead
  - Fixes crash when texture is empty (0px width or height)
  - Fixes Point instruction when new point is appended
  - Fixes to enable support of NPOT texture on android/ios platform
  + Widgets
  - [#401] New Scatter.do_collide_after_children property
  - [#419] New TabbedPanel widget
  - [#437] New TextInput.readonly property
  - [#447] Fix popup background resizing when Window resize
  - [#480] Fixes StackLayout size_hint missing calculation
  - [#485] Fixes VideoPlayer scrollbar with multitouch
  - [#490] Fixes ToggleButton memory leak
  - Add FileChooser.file_encodings for a better unicode conversion
  - Better handling of mousewheel in Button
  - Delayed Label texture creation
  - Enhance RST widget to support :align: in image directive
  - Fixes RST widget to use document root for loading images and
  - New Popup.dismiss(animation) attribute to disable the fadeout when
  - New RstDocument.goto(reference) for scrolling the document to a
  - New Undo/Redo for TextInput
* Fri May  4 2012 prusnak@opensuse.org
- Updated to version 1.2.0
  * Core
  - [#325] New Window.mouse_pos to get the main mouse position anytime
  - [#427] Improved markup positioning with glpyhs+kerning
  - Avoid rendering of empty text lines
  - Fixed setter() and getter() EventDispatcher methods
  - Implement new Dropfile event, to be able to open files on macosx
  - Optimized texture upload from 3 to 1 upload in somes cases
  - The system/Window can now "pause" the application if the app support it
  * Graphics
  - Disable mipmapping for people using Desktop GL kivy < 3.0
  - Enhanced graphics engine to support OpenGL reloading / context-lost
  - Optimized shaders uniform upload if not used
  - Optimized VBO drawing by using a GPU buffer for storing indices
  * Modules
  - [#415] Recorder now record keyboards events
  - [#309] Fixes for inspector / memory leak
  - New webdebugger module for having statistics on the current running app
  * Widget
  - [#331] New VideoPlayer widget: Video + controls buttons, annotations and
  - [#411] Propagate touchs to children for Label and Button
  - [#412] Removed redundant background_texture on Bubble
  - [#416] New background_color and foreground_color to TextInput
  - [#429] New password mode to TextInput
  - [#431] Fixes clipboard for linux, works perfect on linux, windows and mac
  - [#439] Improve performance on TextInput dealing with large text
  - Enhanced FileChooser to delay the file creation over the time, and display
  - Enhance FileChooser to animate when scrollwheel is used
  - Enhance scrollview to animate when scrollwheel is used
  - Fixed Bubble not listening to color changes
  - New FileChooser.rootpath to restrict file browsing
  - New scrollview scrollbar (not touchable)
  - New ".. video::" directive in the RstDocument widget
  - New Video.seek() method
  - Updated filechooser icon theme
  * Examples
  - [#405] New examples dealing with unicode
  * Others
  - [#404] Fixes for msvc9 compilation errors
  - [#424] Fixed pyinstaller packaging for macosx
  - Add installation instructions for mageia
  - New instructions for packaging on iOS
* Wed Feb 29 2012 saschpe@suse.de
- Remove content with non-commercial only license (bnc#749340)
* Mon Feb 20 2012 saschpe@suse.de
- Updated runtime requirements
* Mon Feb 20 2012 saschpe@suse.de
- Update to version 1.1.1:
  * Core
  - [#403] Pygame audio loader doesn't work (in addition to camera opencv provider)
- Changes from version 1.1.0:
  * Core
  - [#319] Allow dynamic changes to url in Loader
  - [#371] Allow BoundedNumericProperty to have custom min/max per widget
  - [#373] Allow Property.dispatch() to be called from Python
  - [#376] Fix list.reverse() in ListProperty
  - [#386] Fix GC with Clock triggered events
  - [#306] Fix video uri support with gstreamer
  - Add support for italic/bold text in core/text
  - Better traceback when an exception happen within kv
  - Enhance properties exceptions
  - Fixes for camera frame update
  - Fixes for python-for-android project
  - Fixes list/dict properties on pop/popitem method
  - Merged android-support branch to master
  - New Atlas class for merging png/jpeg and acces with atlas://
  - New SettingPath in settings
  - New markup text rendering: "[b]Hello[/b] [color=ff0000]World[/color]"
  - New on_pause handler in App: used in android for sleeping
  - Removed text/cairo rendering, ttf doesn't work.
  - Various speedup on cython files
  * Graphics
  - [#375] Fix clear_color in Fbo
  - [#64] New Mesh instruction for custom 2D mesh
  - Fix black screenshot on GLES devices
  - Fix warnings of cython compilation + debian issues
  * Modules
  - [#389] Fix missing image for Touchring
  - New recorder module: you can save and replay touch events
  * Input
  - [#366] Fix time_end never set for all providers except mouse
  - [#377] Removed TUIO provider by default in configuration
  * Lang
  - [#364] Fixes for unicode BOM in .kv
  - Rewrite kvlang parser / builder: improved performance + fixes some design
  * Widget
  - [#317,#334,#335] Fix AsyncImage when source is empty or already loaded
  - [#318] Fix textinput auto scroll
  - [#386] Scatter will not accept touches if none of transformations are enabled
  - [#395] Enhance doc for label/textinput about unicode chars
  - Enhance FileChooser for feedback when item is selected
  - Enhance FileChooser to have a directory selection mode
  - Enhance Popup with more properties for styling
  - Fixes for Textinput focus
  - Fixes Layout when parent are changing
  - Fix for not propagating touch events in Popup
  - Fix Textinput with invalid selection when releasing shift key
  - New Bubble widget, for displaying contextual menu
  - New Copy/Cut/Paste menu in Textinput using Bubble
  - New RstDocument widget, for rendering RST text
  - See http://kivy.org/#changelog for more detail...
- Build HTML documentation and split out doc package
- Fixed several rpmlint issues
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 1.0.7:
  * Core
  - [#32] Implement window rotation (0,90,180,270)
  - [#150] Fix to prevent gcc bug on Mageia
  - [#153] Add packaging doc and hooks for Windows and MacOSX
  - [#155] Replaced import in class methods with late binding
  - [#157] Implement Label.valign support
  - [#166] Prevent to open too many fonts at the same time
  - [#184] Remove unlink() in properties, not needed anymore
  - [#186] Fixes extension support for MacOSX
  - Disable window resizing until we are OpenGL context resistant
  - Enhance extensions wizard and auto-created setup.py
  - Enhance pixels from pygame surface
  - Enhance properties list to prevent memory leak
  - Enhance properties to store data inside Widget class
  - Fixes for Audio class creation
  - Fixes for Clock dictionnary crashes
  - Fixes for volume usage on gstreamer video implementation
  - Fixes infinite loop when we hit max iteration
  - Fixes ordering of Window.add_widget
  - Fixes to avoid resync error with gstreamer
  - New DDS Image loader using new S3TC support
  - New DictProperty property
  * Graphics
  - [#27] Implement mipmap support
  - [#130] Implement caching for Shader source/compilation result
  - [#161] Prevent to upload texture twice when NPOT is supported
  - [#182] Fix Rotation.angle caching with degrees/radians
  - [#190] Fix crash when too many vertices are pushed in VBO
  - Enhance Ellipse to add angle_start/angle_end properties
  - Enhance GridLayout to have minimum and default size per col/row
  - Enhance logging of OpenGL capabilities
  - Enhance texture memory by using native NPOT if available
  - Enhance texture upload by using the best pixel packing
  - Fixes Color.hsv property crashes
  - Fixes for GLES2 by using GL_UNSIGNED_SHORT in VBO
  - Fixes some typo on OpenGL wrapper
  - New $HEADER$ token that can be used in fragment/vertex shader code
  - New OpenGL Utils module for checking texture capabilities and others
  - New S3TC texture support
  - New Texture.colorfmt property
  * Input
  - Enhance Wacom support on linux platform
  - Fix leak/slowdown in MouseMotionEvent
  * Lang
  - [#189] Fixes for not allowing dot in properties name
  - Concat property value when the value is shifted to one level
  - Enhance key resolution ([x for x in list] can be used now.)
  - Enhance module/class resolution at import
  * Widget
  - [#139] Add TreeView.remove_node()
  - [#143] Fix crash when group is changing on ToggleButton
  - [#146] Fix invalid calculation for Image.norm_image_size
  - [#152] Fix Camera.play property
  - [#160] Prevent label creation until text is set
  - [#178] Set default values only on properties
  - Enhance ScrollView to have kind of kinetic movement
  - Fixes calculation of Stacklayout.size with padding
  - Fixes FloatLayout relayout when children size* is changing
  - Fixes for initial Label.font_name assignement
  - Fixes to prevent call of on_release twice
  - Fix ScrollView with grab events
  - New Image.allow_stretch property
  - New Popup (modal popup) widget
  - New Settings widget
  - New Switch widget
  - New Widget.uid property
* Fri Jun 24 2011 saschpe@gmx.de
- Initial version
